/*
 * THE NEMESIS PROJECT
 * Copyright (C) 1999, 2000 Mark Grimes <obecian@packetninja.net>
 *
 * nemesis-arp.h (ARP Packet Injector)
 *
 */


#define TITLE "ARP Packet Injection -=- The NEMESIS Project -=- "
#define VERSION "1.2"
#define CODERS "Copyright (C) 1999, 2000 Mark Grimes <obecian@packetninja.net>"

#include <stdio.h>
#include <strings.h>
#include <stdlib.h>
#include <unistd.h>
#include <netinet/in.h>
#include <sys/types.h>
#include <libnet.h>
#include <pcap.h>

#define PROMISC 1
#define SNAPLEN 128
#define TIMEOUT 1024
#define OPTIMIZE 0
#define PADDING 15

u_int			enet_tmp[6];
u_long          source,		/* source address */
                dest;		/* destination address */
u_char         *payload,	/* payload pointer */
				*pcap_pkt,	/* pcap packet */
				*spkt_data,
                enet_src[6],	/* source MAC address */
                enet_dst[6];	/* destination MAC address */

int             got_link, got_payload;	/* sanity check */
int				arptype;

int             payload_s;	/* payload size */

char           *device;		/* network device */
int 			link_type,
				pcap_offset,
				l3;

struct 			libnet_link_int *l2;

int             verbose;	/* verbosity */

int             buildarp();

void						hexdump(char *, int);
void            usage(char *);
void            defaults();	/* defaults for packet fields */

int             nbytes;

#ifndef IPOPT_SECURITY
#define IPOPT_SECURITY	130
#endif
